@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.4   update date: 2023-03-08
+# Version : 1.4.5   update date: 2023-05-11
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -198,6 +198,11 @@ if [ $? -gt 0 ]; then
   echo "Create group [${USER_NAME}] error."
   exit 3
 fi
+TMPUSER_HOME=${USER_HOME%/*}
+if [ ! -d ${TMPUSER_HOME} ]; then
+  loginfo "Creating directory where user home will build: ${TMPUSER_HOME}" 
+  mkdir -p ${TMPUSER_HOME}
+fi
 useradd -g ${USER_NAME} -d ${USER_HOME:-/home/${USER_NAME}} -m -s /bin/bash ${USER_NAME} 2>/dev/null
 if [ $? -gt 0 ]; then
   echo "Create user [${USER_NAME}] error."
@@ -335,9 +340,21 @@ if [ "x$SOFTONLY" = xy -o "x$SOFTONLY" = xY ];then
   exit 0;
 fi
 
+# fix 330 ddlalert error
+loginfo "Creating file \$INSTALL_DIR/etc/upgraded ."
+if [ ! -f $INSTALL_DIR/etc/upgraded ]; then
+  touch $INSTALL_DIR/etc/upgraded
+  chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/upgraded
+  chmod 0644 $INSTALL_DIR/etc/upgraded
+fi
+
 # oninit
 loginfo "Start run database init: oninit -ivy"
 su - ${USER_NAME} -c "timeout 1800 oninit -ivy"
+if [ ! $? -eq 0 ]; then
+  loginfo "Database init error! Please check online.log."
+  exit 1
+fi
 
 echo -e "OK"
 loginfo "Creating system database.\c"
